Documentation
¶
Overview ¶
The ideas in this code and the load balancer are taken from http://concur.rspace.googlecode.com/hg/talk/concur.html#slide-51
Took substantitial portions of code from https://github.com/michaeldv/mop for this
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AnalyzeAllResponses ¶
Analyze all significant dates with a histogram. But also write any significant data to a csv file so we can do further processing in R
Types ¶
type Analyzer ¶
type Analyzer struct {
// contains filtered or unexported fields
}
func NewAnalyzer ¶
func (*Analyzer) AnalyzeStock ¶
func (a *Analyzer) AnalyzeStock(resp *Response) (ois []OfInterest)
Analyze the stock data
type Options ¶
func NewOptions ¶
func NewOptions() *Options
func (*Options) Add ¶
Really just a convenience method. All possible optional values we are able to add can be found at http://www.gummy-stuff.org/Yahoo-data.htm
type Request ¶
func NewRequest ¶
type Requester ¶
type Requester struct {
// Channel of active work
Work chan Request
// contains filtered or unexported fields
}
func NewRequester ¶
Make a new Requester object.
func (*Requester) MakeRequests ¶
Given a map of companies and their corresponding wikipedia pages, make requests to stats.grok.se so that we can get statistics as to how frequently people are viewing their pages